@@ -46,6 +46,8 @@ static bool compfn(const char *s1, const char *s2)
 }
 
 static const char *PDFStrings[] = { // Keep me ordered please
+  "COILSTATE", // series of string ?
+  "HARDWARE_CONFIG", // series of number ?
   "PDF_CONTROL_GEN_PARS",
   "PDF_CONTROL_PREP_PARS",
   "PDF_CONTROL_RECON_PARS",
@@ -53,6 +55,7 @@ static const char *PDFStrings[] = { // Keep me ordered please
   "PDF_EXAM_PARS",
   "PDF_HARDWARE_PARS",
   "PDF_PREP_PARS",
+  "PDF_PRESCAN_COIL_PARS",
   "PDF_SPT_PARS",
 };
 
@@ -68,10 +71,10 @@ static bool isvalidpdfstring( const char *pdfstring )
 typedef enum
 {
   param_float = 0,
-  param_integer,
-  param_string,
+  param_integer = 1, // 1 << 0
+  param_string = 2, // 1 << 1
   param_3, // ??
-  param_enum,
+  param_enum = 4, // 1 << 2
 } param_type;
 
 static const char *gettypenamefromtype( int i)
@@ -122,16 +125,34 @@ struct header
   void read( std::istream & is )
     {
     is.read( (char*)&v1,sizeof(v1));
-    is.read( (char*)&nints,sizeof(nints));
-    is.read( (char*)&v3,sizeof(v3));
-    assert( v3 == 0 ); // looks like this is always 0
-    is.read( (char*)&v4,sizeof(v4));
-    is.read( (char*)&nfloats,sizeof(nfloats));
-    is.read( (char*)&v6,sizeof(v6));
-    is.read( (char*)&nstrings,sizeof(nstrings));
-    is.read( (char*)&v8,sizeof(v8));
-    assert( v8 == 8 );
-    is.read( (char*)&numparams,sizeof(numparams));
+    if( v1 == 0x01 ) {
+      // direct (FIXME how should we detect this, much like TIFF ???)
+      nints = 0;
+      v3 = 0;
+      v4 = 0;
+      nfloats = 0;
+      v6 = 0;
+      nstrings = 0;
+      v8 = 0;
+      numparams = 0;
+      uint32_t bla;
+      is.read( (char*)&bla, sizeof(bla) );
+      assert( bla == 0x2 || bla == 0x3 );
+      nstrings = 1;
+      numparams = 1;
+    } else {
+      // indirect
+      is.read( (char*)&nints,sizeof(nints));
+      is.read( (char*)&v3,sizeof(v3));
+      assert( v3 == 0 ); // looks like this is always 0
+      is.read( (char*)&v4,sizeof(v4));
+      is.read( (char*)&nfloats,sizeof(nfloats));
+      is.read( (char*)&v6,sizeof(v6));
+      is.read( (char*)&nstrings,sizeof(nstrings));
+      is.read( (char*)&v8,sizeof(v8));
+      assert( v8 == 8 );
+      is.read( (char*)&numparams,sizeof(numparams));
+    }
     }
   void print( std::ostream & os )
     {
@@ -150,29 +171,90 @@ struct header
 struct param
 {
   char name[32+1];
-  int8_t boolean;
+  uint8_t boolean;
   int32_t type;
   uint32_t dim;
-  uint32_t v4;
-  /*int32_t*/ std::streamoff offset;
+  union {
+  uint32_t val;
+  char * ptr; } v4;
+  int32_t /*std::streamoff*/ offset;
   param_type gettype() const { return (param_type)type; }
   uint32_t getdim() const { return dim; }
+  void read_direct_int( std::istream & is ) {
+    uint32_t bla;
+    int max = 9;
+    std::vector<uint32_t> v;
+    for( int i = 0; i < max; ++i ) {
+      is.read( (char*)&bla, sizeof(bla) );
+      v.push_back( bla );
+    }
+    is.read( (char*)&bla, sizeof(bla) );
+    char name0[32];
+    memset(name0,0,sizeof(name0));
+    assert( bla < sizeof(name0) );
+    is.read( name0, bla);
+    size_t l = strlen(name0);
+    assert( l == bla );
+    char * ptr = strdup( name0 );
+    v4.ptr = ptr;
+    type = param_string;
+    dim = 1;
+    offset = 0; // important !
+  }
+  void read_direct_string( std::istream & is ) {
+    uint32_t bla;
+    is.read( (char*)&bla, sizeof(bla) );
+    char name0[32];
+    memset(name0,0,sizeof(name0));
+    assert( bla < sizeof(name0) );
+    is.read( name0, bla);
+    size_t l = strlen(name0);
+    assert( l == bla );
+    memcpy( this->name, name0, bla );
+    is.read( (char*)&bla, sizeof(bla) );
+    assert( bla == 0x1 );
+    is.read( (char*)&bla, sizeof(bla) );
+    char value[32];
+    memset(value,0,sizeof(value));
+    assert( bla < sizeof(value) );
+    is.read( value, bla);
+    is.read( (char*)&bla, sizeof(bla) );
+    assert( bla == 0 ); // trailing stuff ?
+    is.read( (char*)&bla, sizeof(bla) );
+    assert( bla == 0 ); // trailing stuff ?
+    const uint32_t cur = (uint32_t)is.tellg();
+    std::cerr << "offset:" << cur << std::endl;
+    if( cur == 65 )
+      is.read( (char*)&bla, 1 );
+    else if( cur == 66 )
+      is.read( (char*)&bla, 1 );
+    else if( cur == 122 )
+      is.read( (char*)&bla, 2 );
+    else
+      assert(0);
+    type = param_string;
+    dim = 1;
+    // FIXME: store the value in v4 for now:
+    char * ptr = strdup( value );
+    v4.ptr = ptr;
+    offset = 0; // important !
+  }
   void read( std::istream & is )
     {
     is.read( name, 32 + 1);
-    //assert( name[32] == 0 ); // fails sometimes...
     // This is always the same issue the string can contains garbarge from previous run,
     // we need to print only until the first \0 character:
-    assert( strlen( name ) <= 32 ); // sigh
+    assert( strlen( name ) <= 32 );
     is.read( (char*)&boolean,1);
-    assert( boolean == 0 || boolean == 1 ); // some kind of bool...
+    assert( boolean == 0 || boolean == 1 || boolean == 0x69 ); // some kind of bool, or digital trash ?
     is.read( (char*)&type, sizeof( type ) );
     assert( gettypenamefromtype( type ) );
-    is.read( (char*)&dim, sizeof( dim ) );
-    is.read( (char*)&v4, sizeof( v4 ) );
-    //assert( v4 == 0 ); // always 0 ? sometimes not...
-    const std::streamoff cur = is.tellg();
+    is.read( (char*)&dim, sizeof( dim ) ); // number of elements
+    is.read( (char*)&v4.val, sizeof( v4.val ) );
+    assert( v4.val == 0 ); // always 0 ? sometimes not...
+    const uint32_t cur = (uint32_t)is.tellg();
     is.read( (char*)&offset, sizeof( offset ) );
+    assert( offset != 0 );
     offset += cur;
     }
 
@@ -182,11 +264,12 @@ struct param
     os << (int)boolean << ",";
     os << type << ",";
     os << dim << ",";
-    os << v4 << ",";
+    os << v4.val << ",";
     os << offset << std::endl;
     }
   void printvalue( std::ostream & os, std::istream & is ) const
     {
+    if( offset ) {
     is.seekg( offset );
     switch( type )
       {
@@ -205,10 +288,10 @@ struct param
       break;
     case param_integer:
         {
+        int32_t v;
         for( uint32_t idx = 0; idx < dim; ++idx )
           {
           if( idx ) os << ",";
-          int32_t v;
           is.read( (char*)&v, sizeof(v) );
           os << v;
           }
@@ -216,24 +299,40 @@ struct param
       break;
     case param_string:
         {
+        int size = 81;
         std::string v;
-        v.resize( dim );
-        is.read( &v[0], dim );
-        os << v;
+        v.resize( size );
+        for( uint32_t idx = 0; idx < dim; ++idx )
+          {
+          if( idx ) os << ";";
+          is.read( &v[0], size );
+          os << v.c_str();
+          }
         }
       break;
     case param_enum:
         {
+        int32_t v;
         for( uint32_t idx = 0; idx < dim; ++idx )
           {
           if( idx ) os << ",";
-          int32_t v;
           is.read( (char*)&v, sizeof(v) );
           os << v;
           }
         }
       break;
       }
+    } else {
+#if 1
+      // direct
+      assert ( type == param_string );
+      char * ptr = v4.ptr;
+        //std::string v;
+        //v.resize( dim );
+        //is.read( &v[0], dim );
+        os << ptr;
+#endif
+    }
 
     }
   void printxml( std::ostream & os, std::istream & is ) const
@@ -279,7 +378,7 @@ Wotsit ?
   */
   bool ret = false;
 
-  //  (2005,1137) PN (LO) [PDF_CONTROL_GEN_PARS]                    # 20,1 ?
+  //  (2005,1137) PN (LO) [PDF_CONTROL_GEN_PARS]                    # 20,1 Protocol Data Name
   const gdcm::PrivateTag pt0(0x2005,0x37,"Philips MR Imaging DD 002");
   if( !ds.FindDataElement( pt0 ) ) return false;
   const gdcm::DataElement &de0 = ds.GetDataElement( pt0 );
@@ -287,11 +386,23 @@ Wotsit ?
   const gdcm::ByteValue * bv0 = de0.GetByteValue();
   std::string s0( bv0->GetPointer() , bv0->GetLength() );
 
-  // (2005,1139) LO [IEEE_PDF]                                     # 8,1 ?
+  // (2005,1139) LO [IEEE_PDF]                                     # 8,1 Protocol Data Type
   const gdcm::PrivateTag pt1(0x2005,0x39,"Philips MR Imaging DD 002");
   if( !ds.FindDataElement( pt1 ) ) return false;
   const gdcm::DataElement &de1 = ds.GetDataElement( pt1 );
 
+  // (2005,1143) SL 53                                             # 4,1 Protocol Data Block Length (non-padded)
+  const gdcm::PrivateTag pt2(0x2005,0x43,"Philips MR Imaging DD 002");
+  if( !ds.FindDataElement( pt2 ) ) return false;
+  const gdcm::DataElement &de2 = ds.GetDataElement( pt2 );
+
+  // (2005,1147) CS [Y ]                                           # 2,1 Protocol Data Boolean
+  const gdcm::PrivateTag pt3(0x2005,0x47,"Philips MR Imaging DD 002");
+  if( !ds.FindDataElement( pt3 ) ) return false;
+  const gdcm::DataElement &de3 = ds.GetDataElement( pt3 );
+  (void)de3;
+
+  // (2005,1144) OW 00\00\00\00\05\00\00\00\35\2e\31\2e\37\00         # 54,1 Protocol Data Block
   const gdcm::PrivateTag pt(0x2005,0x44,"Philips MR Imaging DD 002");
   if( !ds.FindDataElement( pt ) ) return false;
   const gdcm::DataElement &de = ds.GetDataElement( pt );
@@ -345,40 +456,70 @@ Wotsit ?
     {
     if( de1.IsEmpty() ) return false;
     const gdcm::ByteValue * bv1 = de1.GetByteValue();
+    gdcm::Element<gdcm::VR::SL,gdcm::VM::VM1> dlen = {{0l}};
+    dlen.SetFromDataElement( de2 );
     std::string s1( bv1->GetPointer() , bv1->GetLength() );
 
     if( s1 == "IEEE_PDF" )
       {
-      //  std::cout << "Len= " << bv->GetLength() << std::endl;
-#if 0
-      std::string fn = gdcm::LOComp::Trim( s.c_str() ); // remove trailing space
-      std::ofstream out( fn.c_str() );
-      out.write( bv->GetPointer(), bv->GetLength() );
-      out.close();
-#endif
 
       std::istringstream is;
-      std::string dup( bv->GetPointer(), bv->GetLength() );
+      assert( bv->GetLength() == (size_t)dlen.GetValue() || bv->GetLength() == (size_t)(dlen.GetValue() + 1) );
+      std::string dup( bv->GetPointer(), dlen.GetValue() /*bv->GetLength()*/ );
       is.str( dup );
 
       header h;
       h.read( is );
-#if 0
-      std::cout << s0.c_str() << std::endl;
+      //assert( is.peek() && is.eof() );
+#if 1
+      static int c = 0;
+      std::string fn0 = gdcm::LOComp::Trim( s1.c_str() ); // remove trailing space
+      std::stringstream ss;
+      ss << fn0 << "_" << c++;
+      if( h.v1 == 0x01 )
+        ss << ".direct";
+      else
+        ss << ".indirect";
+      std::cout << "fn0=" << ss.str() << " Len= " << bv->GetLength() << std::endl;
+      std::ofstream out( ss.str().c_str() );
+      out.write( bv->GetPointer(), bv->GetLength() );
+      out.close();
+#endif
+#if 1
+      std::cout << dup.c_str() << std::endl;
       h.print( std::cout );
 #endif
 
-      assert( is.tellg() == std::streampos(0x20) );
-      is.seekg( 0x20 );
-
       std::vector< param > params;
-      param p;
-      for( uint32_t i = 0; i < h.getnparams(); ++i )
-        {
-        p.read( is );
-        //p.print( std::cout );
-        params.push_back( p );
+      if( h.v1 == 0x01 ) {
+        for( uint32_t i = 0; i < 1 /* h.getnparams()*/; ++i ) {
+          param p;
+          if( s0 == "HARDWARE_CONFIG " )
+            {
+            p.read_direct_int( is );
+            }
+          else if( s0 == "COILSTATE " )
+            {
+            p.read_direct_string( is );
+            }
+          else
+            {
+            assert(0);
+            }
+          params.push_back( p );
         }
+      } else {
+        assert( is.tellg() == std::streampos(0x20) );
+        is.seekg( 0x20 );
+
+        param p;
+        for( uint32_t i = 0; i < h.getnparams(); ++i )
+          {
+          p.read( is );
+          //p.print( std::cout );
+          params.push_back( p );
+          }
+      }
 
       std::string fn = gdcm::LOComp::Trim( s0.c_str() ); // remove trailing space
       bool b1 = isvalidpdfstring( fn.c_str() );
@@ -535,7 +676,9 @@ int main(int argc, char *argv[])
 
     gdcm::DataSet &nestedds = item.GetNestedDataSet();
 
-    if( !ProcessNested( nestedds ) ) return 1;
+    if( !ProcessNested( nestedds ) ) {
+      std::cerr << "Error processing Item #" << i << std::endl;
+    }
     }
 
   return 0;
