@@ -63,7 +63,8 @@ static bool GetOriginValueFromSequence(const DataSet& ds, const Tag& tfgs, std::
   if( !subds.FindDataElement(tpms) ) return false;
   //const SequenceOfItems * sqi2 = subds.GetDataElement( tpms ).GetSequenceOfItems();
   SmartPointer<SequenceOfItems> sqi2 = subds.GetDataElement( tpms ).GetValueAsSQ();
-  assert( sqi2 );
+  if( sqi2 && !sqi2->IsEmpty() )
+  {
   const Item &item2 = sqi2->GetItem(1);
   const DataSet & subds2 = item2.GetNestedDataSet();
   //
@@ -79,6 +80,8 @@ static bool GetOriginValueFromSequence(const DataSet& ds, const Tag& tfgs, std::
   ori.push_back( at.GetValue(2) );
 
   return true;
+  }
+  return false;
 }
 
 static bool GetDirectionCosinesValueFromSequence(const DataSet& ds, const Tag& tfgs, std::vector<double> &dircos)
@@ -423,7 +426,9 @@ std::vector<double> ImageHelper::GetOriginValue(File const & f)
    || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
    || ms == MediaStorage::XRay3DAngiographicImageStorage
    || ms == MediaStorage::XRay3DCraniofacialImageStorage
-   || ms == MediaStorage::SegmentationStorage )
+   || ms == MediaStorage::SegmentationStorage
+   || ms == MediaStorage::IVOCTForProcessing
+   || ms == MediaStorage::IVOCTForPresentation)
     {
     const Tag t1(0x5200,0x9229);
     const Tag t2(0x5200,0x9230);
@@ -545,7 +550,9 @@ std::vector<double> ImageHelper::GetDirectionCosinesValue(File const & f)
    || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
    || ms == MediaStorage::XRay3DAngiographicImageStorage
    || ms == MediaStorage::XRay3DCraniofacialImageStorage
-   || ms == MediaStorage::SegmentationStorage )
+   || ms == MediaStorage::SegmentationStorage
+   || ms == MediaStorage::IVOCTForPresentation
+   || ms == MediaStorage::IVOCTForProcessing )
     {
     const Tag t1(0x5200,0x9229);
     const Tag t2(0x5200,0x9230);
@@ -857,7 +864,9 @@ void ImageHelper::SetDimensionsValue(File& f, const Pixmap & img)
    || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
    || ms == MediaStorage::XRay3DAngiographicImageStorage
    || ms == MediaStorage::XRay3DCraniofacialImageStorage
-   || ms == MediaStorage::SegmentationStorage )
+   || ms == MediaStorage::SegmentationStorage
+   || ms == MediaStorage::IVOCTForProcessing
+   || ms == MediaStorage::IVOCTForPresentation )
     {
       const Tag tfgs(0x5200,0x9230);
       if( ds.FindDataElement( tfgs ) )
@@ -969,12 +978,14 @@ std::vector<double> ImageHelper::GetRescaleInterceptSlopeValue(File const & f)
       const DataElement &priv_rescaleslope = ds.GetDataElement( tpriv_rescaleslope );
       Element<VR::DS,VM::VM1> el_ri = {{ 0 }};
       el_ri.SetFromDataElement( priv_rescaleintercept );
-      Element<VR::DS,VM::VM1> el_rs = {{ 0 }};
+      Element<VR::DS,VM::VM1> el_rs = {{ 1 }};
       el_rs.SetFromDataElement( priv_rescaleslope );
       if( PMSRescaleInterceptSlope )
       {
         interceptslope[0] = el_ri.GetValue();
         interceptslope[1] = el_rs.GetValue();
+        if( interceptslope[1] == 0 )
+          interceptslope[1] = 1;
         gdcmWarningMacro( "PMS Modality LUT loaded for MR Image Storage: [" << interceptslope[0] << "," << interceptslope[1] << "]" );
       }
       }
@@ -1036,6 +1047,8 @@ Tag ImageHelper::GetSpacingTagFromMediaStorage(MediaStorage const &ms)
   case MediaStorage::PhilipsPrivateMRSyntheticImageStorage:
   case MediaStorage::VLPhotographicImageStorage: // VL Image IOD
   case MediaStorage::VLMicroscopicImageStorage:
+  case MediaStorage::IVOCTForProcessing:
+  case MediaStorage::IVOCTForPresentation:
     // (0028,0030) DS [2.0\2.0]                                #   8, 2 PixelSpacing
     t = Tag(0x0028,0x0030);
     break;
@@ -1187,7 +1200,9 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
     || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
     || ms == MediaStorage::XRay3DAngiographicImageStorage
     || ms == MediaStorage::XRay3DCraniofacialImageStorage
-    || ms == MediaStorage::SegmentationStorage )
+    || ms == MediaStorage::SegmentationStorage
+    || ms == MediaStorage::IVOCTForProcessing
+    || ms == MediaStorage::IVOCTForPresentation)
     {
     // <entry group="5200" element="9230" vr="SQ" vm="1" name="Per-frame Functional Groups Sequence"/>
     const Tag t1(0x5200,0x9229);
@@ -1457,7 +1472,9 @@ void ImageHelper::SetSpacingValue(DataSet & ds, const std::vector<double> & spac
    || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
    || ms == MediaStorage::XRay3DAngiographicImageStorage
    || ms == MediaStorage::XRay3DCraniofacialImageStorage
-   || ms == MediaStorage::SegmentationStorage )
+   || ms == MediaStorage::SegmentationStorage
+   || ms == MediaStorage::IVOCTForPresentation
+   || ms == MediaStorage::IVOCTForProcessing )
     {
 /*
     (0028,9110) SQ (Sequence with undefined length #=1)     # u/l, 1 PixelMeasuresSequence
@@ -1770,7 +1787,9 @@ void ImageHelper::SetOriginValue(DataSet & ds, const Image & image)
    && ms != MediaStorage::XRay3DCraniofacialImageStorage
    && ms != MediaStorage::EnhancedMRImageStorage
    && ms != MediaStorage::EnhancedPETImageStorage
-   && ms != MediaStorage::EnhancedCTImageStorage )
+   && ms != MediaStorage::EnhancedCTImageStorage
+   && ms != MediaStorage::IVOCTForPresentation
+   && ms != MediaStorage::IVOCTForProcessing )
     {
     // FIXME: should I remove the ipp tag ???
     return;
@@ -1783,7 +1802,9 @@ void ImageHelper::SetOriginValue(DataSet & ds, const Image & image)
    || ms == MediaStorage::XRay3DCraniofacialImageStorage
    || ms == MediaStorage::MultiframeGrayscaleWordSecondaryCaptureImageStorage
    || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
-   || ms == MediaStorage::SegmentationStorage )
+   || ms == MediaStorage::SegmentationStorage
+   || ms == MediaStorage::IVOCTForPresentation
+   || ms == MediaStorage::IVOCTForProcessing )
     {
 /*
     (0020,9113) SQ (Sequence with undefined length #=1)     # u/l, 1 PlanePositionSequence
@@ -1819,7 +1840,31 @@ void ImageHelper::SetOriginValue(DataSet & ds, const Image & image)
       ipp.SetValue( new_origin[2], 2);
       SetDataElementInSQAsItemNumber(ds, ipp.GetAsDataElement(), tfgs, i+1);
       }
+    // cleanup the sharedgroup:
+    {
+      const Tag tfgs0(0x5200,0x9229);
+      if( ds.FindDataElement( tfgs0 ) )
+      {
+        SmartPointer<SequenceOfItems> sqi = ds.GetDataElement( tfgs0 ).GetValueAsSQ();
+        assert( sqi );
+        SequenceOfItems::SizeType nitems = sqi->GetNumberOfItems();
+        for(SequenceOfItems::SizeType i0 = 1; i0 <= nitems; ++i0)
+        {
+          // Get first item:
+          Item &item = sqi->GetItem(i0);
+          DataSet & subds = item.GetNestedDataSet();
+          const Tag tpms(0x0020,0x9113);
+          subds.Remove(tpms);
+        }
+      }
+    }
+    // Cleanup root level:
+    {
+    const Tag tiop(0x0020,0x0032);
+    ds.Remove(tiop);
+    }
 
+ 
     // C.7.6.6.1.2 Frame Increment Pointer
     // (0028,0009) AT (0018,2005)                                        # 4,1-n Frame Increment Pointer
     if( ms == MediaStorage::MultiframeGrayscaleWordSecondaryCaptureImageStorage
@@ -1871,7 +1916,9 @@ void ImageHelper::SetDirectionCosinesValue(DataSet & ds, const std::vector<doubl
    && ms != MediaStorage::XRay3DCraniofacialImageStorage
    && ms != MediaStorage::EnhancedMRImageStorage
    && ms != MediaStorage::EnhancedPETImageStorage
-   && ms != MediaStorage::EnhancedCTImageStorage )
+   && ms != MediaStorage::EnhancedCTImageStorage
+   && ms != MediaStorage::IVOCTForPresentation
+   && ms != MediaStorage::IVOCTForProcessing )
     {
     // FIXME: should I remove the iop tag ???
     return;
@@ -1903,7 +1950,9 @@ void ImageHelper::SetDirectionCosinesValue(DataSet & ds, const std::vector<doubl
    || ms == MediaStorage::MultiframeGrayscaleByteSecondaryCaptureImageStorage
    || ms == MediaStorage::XRay3DAngiographicImageStorage
    || ms == MediaStorage::XRay3DCraniofacialImageStorage
-   || ms == MediaStorage::SegmentationStorage )
+   || ms == MediaStorage::SegmentationStorage
+   || ms == MediaStorage::IVOCTForPresentation
+   || ms == MediaStorage::IVOCTForProcessing )
     {
 /*
     (0020,9116) SQ (Sequence with undefined length #=1)     # u/l, 1 PlaneOrientationSequence
@@ -1980,6 +2029,11 @@ void ImageHelper::SetDirectionCosinesValue(DataSet & ds, const std::vector<doubl
         }
       }
     }
+    // Cleanup root level:
+    {
+    const Tag tiop(0x0020,0x0037);
+    ds.Remove(tiop);
+    }
 
     return;
     }
@@ -2009,7 +2063,9 @@ void ImageHelper::SetRescaleInterceptSlopeValue(File & f, const Image & img)
    && ms != MediaStorage::EnhancedPETImageStorage
    && ms != MediaStorage::XRay3DAngiographicImageStorage
    && ms != MediaStorage::XRay3DCraniofacialImageStorage
-   && ms != MediaStorage::SegmentationStorage )
+   && ms != MediaStorage::SegmentationStorage
+   && ms != MediaStorage::IVOCTForPresentation
+   && ms != MediaStorage::IVOCTForProcessing )
     {
     if( img.GetIntercept() != 0. || img.GetSlope() != 1. )
       {
@@ -2108,6 +2164,15 @@ void ImageHelper::SetRescaleInterceptSlopeValue(File & f, const Image & img)
         }
       }
     }
+    // cleanup root (famous MR -> EMR case) 
+    {
+    const Tag t1(0x0028,0x1052);
+    ds.Remove(t1);
+    const Tag t2(0x0028,0x1053);
+    ds.Remove(t2);
+    const Tag t3(0x0028,0x1053);
+    ds.Remove(t3);
+    }
     return;
     }
 
